import struct


class Unpacker:
    """
    A wrapper around struct.unpack() to unpack binary data without having to
    explicitly define the byte order in the format string. Also restrict the
    type of format to str and buffer to bytes.
    """
    def __init__(self, byte_order_char: str = '') -> None:
        self.byte_order_char = byte_order_char

    def unpack(self, format: str, buffer: bytes):
        """
        Unpack a string of bytes into a tuple of values based on the given
        format
        :param format: the format used to unpack the byte string
        :param buffer: the byte string
        :return: a tuple containing the unpacked values.
        """
        default_byte_order_chars = ('@', '=', '>', '<', '!')
        if format.startswith(default_byte_order_chars):
            format = self.byte_order_char + format[:1]
        else:
            format = self.byte_order_char + format
        return struct.unpack(format, buffer)
